@@ -240,7 +240,7 @@ class Validation(object):
 
 
     def validate_metrics_request(request, port_ids):
-        if request.choice != 'port':
+        if request.choice is not None and request.choice != 'port':
             raise SnappiTrexException('\'{}\' is not a supported metrics choice'.format(request.choice))
         if request.port.port_names is not None:
             for p_name in request.port.port_names:
